﻿package packages {
	
    public class PageContainer {
		
		import flash.events.*;
		import flash.display.Sprite;
		import flash.display.Shape;
		import flash.net.URLLoader;
		import flash.net.URLRequest;
		
		import packages.Globals;
		import packages.Page;
		
		var XMLLoader:URLLoader;
		var pagesXML:XML;
		var container:Sprite;
		var pagecontainer:Sprite;
		var pageselect:Sprite;
		var detailpage:Page;
		var pages:Array;
		var Xpos:Number;
		var Ypos:Number;
		var ScrollHandler:handler;
		var ScrollTrack:track;
		var minScroll:Number;
		var maxScroll:Number;
		var OffsetX:Number;
		var scrollfactor:Number;
		
		//CONSTRUCTOR:
		public function PageContainer(url:String) {
			var XMLurl:URLRequest = new URLRequest(url);
			XMLLoader = new URLLoader(XMLurl);
			Xpos = Globals.FIRSTPOS;
			Ypos = Globals.SPACING;
			container = new Sprite();
			pagecontainer = new Sprite();
			pageselect = new Sprite();
			ScrollHandler = new handler();
			ScrollTrack = new track();
			ScrollHandler.height = Globals.SCROLL_HEIGHT;
			ScrollTrack.height = Globals.SCROLL_HEIGHT;
			XMLLoader.addEventListener("complete", XMLLoaded);
		}
		
		private function XMLLoaded(event:Event):void {
			pagesXML = new XML(XMLLoader.data);
			pages = new Array(pagesXML.PAGE.length());
			var i:int = 0;
			for each (var pageXML in pagesXML.PAGE) {
				var page:Page = new Page(pageXML);
				page.SetCoords(Xpos, Ypos);
				Xpos += page.GetWidth() + Globals.SPACING;
				pagecontainer.addChild(page);
				pages[i] = page;
				pages[i].addEventListener(MouseEvent.MOUSE_DOWN, PageSelect);
				i++;
			}
			pageselect.graphics.lineStyle(3, 0x000000);
			pageselect.graphics.drawRect(pages[0].x, pages[0].y, pages[0].width, pages[0].height);
			pagecontainer.addChild(pageselect);
			container.addChild(pagecontainer);
			DrawScrollbar();
			DrawMask();
			CreateDetailPage(1);
		}
		
		private function DrawScrollbar():void {
			ScrollTrack.x = Globals.FIRSTPOS;
			ScrollTrack.y = Globals.THUMB_HEIGHT + 2 * Globals.SPACING;
			ScrollHandler.x = Globals.FIRSTPOS;
			ScrollHandler.y = Globals.THUMB_HEIGHT + 2 * Globals.SPACING;
			container.addChild(ScrollTrack);
			container.addChild(ScrollHandler);
			minScroll = ScrollHandler.x;
			maxScroll = ScrollTrack.width + Globals.FIRSTPOS;
			scrollfactor = ScrollTrack.width / (Xpos - Globals.FIRSTPOS - Globals.SPACING);
			ScrollHandler.width = scrollfactor * ScrollTrack.width;
			ScrollHandler.buttonMode = true;
			ScrollHandler.addEventListener(MouseEvent.MOUSE_DOWN, StartDrag);
			container.parent.addEventListener(MouseEvent.MOUSE_UP, StopDrag);
			ScrollHandler.addEventListener(MouseEvent.MOUSE_OVER, ScrollOver);
			ScrollHandler.addEventListener(MouseEvent.MOUSE_OUT, ScrollOut);
		}
		
		private function DrawMask():void {
			var maskshape:Shape = new Shape();
			maskshape.graphics.lineStyle(1, 0x000000);
			maskshape.graphics.beginFill(0xff0000);
			maskshape.graphics.drawRect(Globals.FIRSTPOS, 0, ScrollTrack.width, container.stage.stageHeight);
			pagecontainer.mask = maskshape;
		}
		
		//EVENTS:
		private function PageSelect(event:MouseEvent):void {
			pageselect.x = event.target.parent.x - Globals.FIRSTPOS;
			RemoveDetailPage();
			var str:String = event.target.parent.name;
			CreateDetailPage(Number(str.substring(4, str.length)));
		}
		
		public function RemoveDetailPage():void {
			container.parent.removeChild(container.parent.getChildByName("detailpage"));
			Globals.currentPage = 0;
		}
		
		public function CreateDetailPage(i:Number):void {
			detailpage = new Page(pagesXML.PAGE[i - 1], false, container.stage.stageHeight - Globals.BUTTON_HEIGHT - 5 * Globals.SPACING - Globals.THUMB_HEIGHT - Globals.SCROLL_HEIGHT);
			detailpage.SetCoords((container.stage.stageWidth - detailpage.GetWidth()) / 2, Globals.BUTTON_HEIGHT + 2 * Globals.SPACING);
			container.parent.addChild(detailpage);
			Globals.currentPage = i;
		}
		
		private function StartDrag(event:MouseEvent):void {
			OffsetX = event.stageX - ScrollHandler.x;
			container.parent.addEventListener(MouseEvent.MOUSE_MOVE, Drag);
		}
		
		private function Drag(event:MouseEvent):void {
			ScrollHandler.alpha = Globals.ALPHA_VALUE;
			ScrollHandler.x = event.stageX - OffsetX;
			pagecontainer.x = (-(event.stageX - OffsetX) + Globals.FIRSTPOS) / scrollfactor;
			if(ScrollHandler.x + ScrollHandler.width >= maxScroll) {
				ScrollHandler.x = maxScroll - ScrollHandler.width;
				pagecontainer.x = -pagecontainer.width + ScrollTrack.width;
			}
			if(ScrollHandler.x <= minScroll) {
				ScrollHandler.x = minScroll;
				pagecontainer.x = -ScrollHandler.x + Globals.FIRSTPOS;
			}
			event.updateAfterEvent();
		}
		
		private function StopDrag(event:MouseEvent):void {
			container.parent.removeEventListener(MouseEvent.MOUSE_MOVE, Drag);
			if((event.stageY < ScrollHandler.y || event.stageY > ScrollHandler.y + ScrollHandler.height) || (event.stageX < ScrollHandler.x || event.stageX > ScrollHandler.x + ScrollHandler.width)) {
				ScrollHandler.alpha = 1;
			}
		}
		
		private function ScrollOver(event:MouseEvent):void { ScrollHandler.alpha = Globals.ALPHA_VALUE; }
		private function ScrollOut(event:MouseEvent):void  { ScrollHandler.alpha = 1; }
		
		//ACCESSORS:
		public function GetPageContainer():Sprite    { return pagecontainer; }
		public function GetPageAt(index:Number):Page { return pages[index]; }
		public function GetContainer():Sprite        { return container; }
		
		//MUTATOR:
		public function SetVisibility(vis:Boolean):void { 
			container.visible = vis;
		}
		
		public function SetWidth(W:Number):void { 
			ScrollTrack.width = W;
			pagecontainer.x = 0;
			DrawScrollbar();
			DrawMask();
		}
		
		public function SetY(Y:Number):void { 
			container.y = Y;
		}
	}
}